@@ -136,6 +136,12 @@ class CurlClient
     eomFunc_ = eomFunc;
   }
 
+  void setOnBodyFunc(
+      const std::function<void(const proxygen::HTTPMessage& request,
+                               const folly::IOBuf* chainBuf)>& onBodyFunc) {
+    onBodyFunc_ = onBodyFunc;
+  }
+
  protected:
   void sendBodyFromFile();
 
@@ -169,6 +175,10 @@ class CurlClient
 
   folly::Optional<std::function<void()>> eomFunc_;
 
+  folly::Optional<std::function<void(const proxygen::HTTPMessage& request,
+                                     const folly::IOBuf* chainBuf)>>
+      onBodyFunc_;
+
   friend class CurlPushHandler;
 };
 
