@@ -29,32 +29,6 @@ namespace {
 using namespace quic::samples;
 using namespace proxygen;
 
-class HQServerTransportFactory : public quic::QuicServerTransportFactory {
- public:
-  explicit HQServerTransportFactory(
-      const HQServerParams& params,
-      HTTPTransactionHandlerProvider httpTransactionHandlerProvider,
-      std::function<void(HQSession*)> onTransportReadyFn_);
-  ~HQServerTransportFactory() override = default;
-
-  // Creates new quic server transport
-  quic::QuicServerTransport::Ptr make(
-      folly::EventBase* evb,
-      std::unique_ptr<quic::FollyAsyncUDPSocketAlias> socket,
-      const folly::SocketAddress& /* peerAddr */,
-      quic::QuicVersion quicVersion,
-      std::shared_ptr<const fizz::server::FizzServerContext> ctx) noexcept
-      override;
-
- private:
-  // Configuration params
-  const HQServerParams& params_;
-  // Provider of HTTPTransactionHandler
-  HTTPTransactionHandlerProvider httpTransactionHandlerProvider_;
-  std::function<void(HQSession*)> onTransportReadyFn_;
-  folly::EventBaseLocal<wangle::ConnectionManager::UniquePtr> connMgr_;
-};
-
 /**
  * HQSessionController creates new HQSession objects
  *
@@ -143,6 +117,8 @@ class QuicAcceptCB : public quic::QuicSocket::ConnectionSetupCallback {
       session->setEgressSettings(
           {{proxygen::SettingsId::ENABLE_CONNECT_PROTOCOL, 1},
            {proxygen::SettingsId::_HQ_DATAGRAM_DRAFT_8, 1},
+           {proxygen::SettingsId::_HQ_DATAGRAM, 1},
+           {proxygen::SettingsId::_HQ_DATAGRAM_RFC, 1},
            {proxygen::SettingsId::ENABLE_WEBTRANSPORT, 1}});
 
       session->startNow();
@@ -201,6 +177,10 @@ void HQSessionController::detachSession(const HTTPSessionBase* /*session*/) {
   }
 }
 
+} // namespace
+
+namespace quic::samples {
+
 HQServerTransportFactory::HQServerTransportFactory(
     const HQServerParams& params,
     HTTPTransactionHandlerProvider httpTransactionHandlerProvider,
@@ -240,21 +220,17 @@ QuicServerTransport::Ptr HQServerTransportFactory::make(
   return transport;
 }
 
-} // namespace
-
-namespace quic::samples {
-
 HQServer::HQServer(
     HQServerParams params,
     HTTPTransactionHandlerProvider httpTransactionHandlerProvider,
     std::function<void(proxygen::HQSession*)> onTransportReadyFn)
-    : params_(std::move(params)),
-      server_(quic::QuicServer::createQuicServer()) {
+    : params_(std::move(params)) {
+  params_.transportSettings.datagramConfig.enabled = true;
+  server_ = quic::QuicServer::createQuicServer(params_.transportSettings);
+
   server_->setBindV6Only(false);
   server_->setCongestionControllerFactory(
       std::make_shared<ServerCongestionControllerFactory>());
-  params_.transportSettings.datagramConfig.enabled = true;
-  server_->setTransportSettings(params_.transportSettings);
 
   server_->setQuicServerTransportFactory(
       std::make_unique<HQServerTransportFactory>(
