@@ -21,7 +21,8 @@ class NoPathIndexingStrategy : public HeaderIndexingStrategy {
 
   // For compression simulations we do not want to index :path headers
   bool indexHeader(const HPACKHeaderName& name,
-                   folly::StringPiece value) const override {
+                   folly::StringPiece value,
+                   bool) const override {
     if (name.getHeaderCode() == HTTP_HEADER_COLON_PATH) {
       return false;
     } else {
