@@ -54,6 +54,7 @@ enum class HQVersion : uint8_t {
 
 extern const std::string kH3;
 extern const std::string kH3AliasV1;
+extern const std::string kH3AliasV2;
 extern const std::string kHQ;
 extern const std::string kH3FBCurrentDraft;
 // TODO: Remove these constants, the session no longer negotiates these
@@ -158,6 +159,10 @@ class HQSession
     }
   }
 
+  std::shared_ptr<QuicProtocolInfo> getQuicInfo() {
+    return quicInfo_;
+  }
+
   void setForceUpstream1_1(bool force) {
     forceUpstream1_1_ = force;
   }
@@ -165,6 +170,10 @@ class HQSession
     strictValidation_ = strictValidation;
   }
 
+  void setEnableEgressPrioritization(bool enableEgressPrioritization) {
+    enableEgressPrioritization_ = enableEgressPrioritization;
+  }
+
   void setSessionStats(HTTPSessionStats* stats) override;
 
   void onNewBidirectionalStream(quic::StreamId id) noexcept override;
@@ -758,6 +767,9 @@ class HQSession
   // for session logic.
   ServerPushLifecycleCallback* serverPushLifecycleCb_{nullptr};
 
+  // Debug feature to test the impact of request body prioritization.
+  bool enableEgressPrioritization_{true};
+
  private:
   std::unique_ptr<HTTPCodec> createStreamCodec(quic::StreamId streamId);
 
@@ -2050,6 +2062,18 @@ class HQSession
     return const_cast<HTTPSessionObserverContainer*>(
         &sessionObserverContainer_);
   }
+
+  class WriteScheduler : public folly::EventBase::LoopCallback {
+   public:
+    explicit WriteScheduler(HQSession& session) : session_(session) {
+    }
+    ~WriteScheduler() override = default;
+    void runLoopCallback() noexcept override;
+
+   private:
+    HQSession& session_;
+  };
+  WriteScheduler writeScheduler_{*this};
 }; // HQSession
 
 std::ostream& operator<<(std::ostream& os, HQSession::DrainState drainState);
