@@ -1077,6 +1077,20 @@ void HTTPTransaction::sendHeadersWithOptionalEOM(const HTTPMessage& headers,
     if (transportCallback_) {
       transportCallback_->bodyBytesGenerated(0);
     }
+    if (txnObserverContainer_.hasObserversForEvent<
+            HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+      const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                         .setTimestamp(proxygen::SteadyClock::now())
+                         .setType(HTTPTransactionObserverInterface::
+                                      TxnBytesEvent::Type::BODY_BYTES_GENERATED)
+                         .setNumBytes(0)
+                         .build();
+      txnObserverContainer_.invokeInterfaceMethod<
+          HTTPTransactionObserverInterface::Events::TxnBytes>(
+          [&e](auto observer, auto observed) {
+            observer->onBytesEvent(observed, e);
+          });
+    }
     if (!validateEgressStateTransition(
             HTTPTransactionEgressSM::Event::eomFlushed)) {
       return;
@@ -1159,6 +1173,20 @@ bool HTTPTransaction::sendHeadersWithDelegate(
     transportCallback_->headerBytesGenerated(size);
     transportCallback_->bodyBytesGenerated(dataFrameHeaderSize);
   }
+  if (txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                       .setTimestamp(proxygen::SteadyClock::now())
+                       .setType(HTTPTransactionObserverInterface::
+                                    TxnBytesEvent::Type::BODY_BYTES_GENERATED)
+                       .setNumBytes(dataFrameHeaderSize)
+                       .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
   updateEgressCompressionInfo(transport_.getCodec().getCompressionInfo());
   return true;
 }
@@ -1296,6 +1324,20 @@ size_t HTTPTransaction::sendDeferredBody(uint32_t maxEgress) {
   if (transportCallback_) {
     transportCallback_->bodyBytesGenerated(nbytes);
   }
+  if (txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                       .setTimestamp(proxygen::SteadyClock::now())
+                       .setType(HTTPTransactionObserverInterface::
+                                    TxnBytesEvent::Type::BODY_BYTES_GENERATED)
+                       .setNumBytes(nbytes)
+                       .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
   return nbytes;
 }
 
@@ -1490,6 +1532,21 @@ void HTTPTransaction::sendEOM() {
       if (transportCallback_) {
         transportCallback_->bodyBytesGenerated(nbytes);
       }
+      if (txnObserverContainer_.hasObserversForEvent<
+              HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+        const auto e =
+            HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                .setTimestamp(proxygen::SteadyClock::now())
+                .setType(HTTPTransactionObserverInterface::TxnBytesEvent::Type::
+                             BODY_BYTES_GENERATED)
+                .setNumBytes(nbytes)
+                .build();
+        txnObserverContainer_.invokeInterfaceMethod<
+            HTTPTransactionObserverInterface::Events::TxnBytes>(
+            [&e](auto observer, auto observed) {
+              observer->onBytesEvent(observed, e);
+            });
+      }
     } else {
       // If the txn is enqueued, sendDeferredBody()
       // should take care of sending the EOM.
