@@ -559,8 +559,8 @@ void testSetQueryParam(const string& url,
   bool expectedChange = (url != expectedUrl);
   EXPECT_EQ(msg.setQueryParam(queryParam, paramValue), expectedChange);
 
-  EXPECT_EQ(msg.getURL(), expectedUrl);
-  EXPECT_EQ(msg.getQueryStringAsStringPiece(), expectedQuery);
+  EXPECT_TRUE(urlsAreEquivalent(msg.getURL(), expectedUrl));
+  EXPECT_TRUE(queryStringsAreEquivalent(msg.getQueryString(), expectedQuery));
 }
 
 TEST(HTTPMessage, SetQueryParamTests) {
@@ -840,28 +840,27 @@ TEST(HTTPMessage, SchemeMasque) {
 TEST(HTTPMessage, StrictMode) {
   HTTPMessage message;
   EXPECT_FALSE(message.setURL("/foo\xff", /*strict=*/true));
-  EXPECT_EQ(message.getURL(), "/foo\xff");
+  EXPECT_TRUE(urlsAreEquivalent(message.getURL(), "/foo\xff"));
   EXPECT_EQ(message.getPath(), "");
 
   message.setURL("/");
   // Not strict mode, high ascii OK
   EXPECT_TRUE(message.setQueryString("a=b\xff"));
-  EXPECT_EQ(message.getURL(), "/?a=b\xff");
+  EXPECT_TRUE(urlsAreEquivalent(message.getURL(), "/?a=b\xff"));
   EXPECT_EQ(message.getPath(), "/");
   EXPECT_EQ(message.getQueryString(), "a=b\xff");
 
   EXPECT_TRUE(message.setQueryString("a=b"));
-  EXPECT_EQ(message.getURL(), "/?a=b");
+  EXPECT_TRUE(urlsAreEquivalent(message.getURL(), "/?a=b"));
   EXPECT_FALSE(message.setQueryString("a=b\xff", /*strict=*/true));
-  EXPECT_EQ(message.getURL(), "/?a=b\xff");
+  EXPECT_TRUE(urlsAreEquivalent(message.getURL(), "/?a=b\xff"));
   EXPECT_EQ(message.getQueryString(), "");
 
   EXPECT_TRUE(message.setQueryString("a=b"));
   EXPECT_FALSE(message.setQueryParam("c", "d\xff", /*strict=*/true));
-  EXPECT_EQ(message.getURL(), "/?a=b&c=d\xff");
-  EXPECT_EQ(message.getQueryString(), "");
+  EXPECT_TRUE(urlsAreEquivalent(message.getURL(), "/?a=b&c=d\xff"));
   EXPECT_TRUE(message.setQueryParam("c", "d\xff", /*strict=*/false));
-  EXPECT_EQ(message.getURL(), "/?a=b&c=d\xff");
+  EXPECT_TRUE(urlsAreEquivalent(message.getURL(), "/?a=b&c=d\xff"));
 
   // Can remove a param without failing the strict parsing
   EXPECT_TRUE(message.setURL("/?a=b&c=d\xff"));
