@@ -8,8 +8,8 @@
 
 #include <folly/FileUtil.h>
 #include <folly/SocketAddress.h>
-#include <folly/dynamic.h>
-#include <folly/json.h>
+#include <folly/json/dynamic.h>
+#include <folly/json/json.h>
 #include <proxygen/lib/pools/generators/FileServerListGenerator.h>
 #include <sstream>
 
@@ -27,7 +27,8 @@ void FileServerListGenerator::FileGenerator::readFile(std::string& filePath,
     folly::throw_exception<Exception>("Error reading file %s", filePath);
   }
 }
-void FileServerListGenerator::FileGenerator::cancelServerListRequest(){};
+void FileServerListGenerator::FileGenerator::cancelServerListRequest() {
+}
 
 void FileServerListGenerator::FileGenerator::run(milliseconds /*timeout*/) {
   // Read the file
